==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/applications/wizard/ActionsCreationState.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

// Include .h file
#include "ActionsCreationState.h"
#include "ActionsCreationWidget.h"
#include "DorothyMainWindow.h"
#include "ActionExtensionCreationState.h"

// includes from coreschema
#include <ActionExtension.hxx>
#include <Actions.hxx>

/**  Constructor */
ActionsCreationState::ActionsCreationState(QString name, ActionsCreationWidget * widget, DorothyMainWindow * mainWindow, ActionExtensionCreationState * parent)
    : WizardState(name, widget, mainWindow, parent)
{
    this->domActionExtension = NULL;
}

/**  Destructor */
ActionsCreationState::~ActionsCreationState() {}

void ActionsCreationState::resetDomActionExtension(cepcoreschema::ActionExtension * domActionExtension)
{
    this->domActionExtension = domActionExtension;
    ActionsCreationWidget * actionsCreationWidget = dynamic_cast<ActionsCreationWidget *> (widget);
    if (actionsCreationWidget != NULL)
    {
        actionsCreationWidget->setToDefault();
    }
}

void ActionsCreationState::onEntry(QEvent * event)
{
    WizardState::onEntry(event);

    ActionsCreationWidget * actionsCreationWidget = dynamic_cast<ActionsCreationWidget *> (widget);
    if (actionsCreationWidget != NULL)
    {
        QString actionExtensionName = domActionExtension->name().c_str();
        actionsCreationWidget->setGroupBoxTitle(actionExtensionName);

        actionsCreationWidget->emptyExistingActions();
        cepcoreschema::Actions theActions = domActionExtension->actions();
        cepcoreschema::Actions::action_iterator it;
        for (it = theActions.action().begin(); it != theActions.action().end(); it++)
        {
            QString actionName = (*it).name().c_str();
            actionsCreationWidget->addActionName(actionName);
        }
    }
}

void ActionsCreationState::onExit( QEvent * event )
{
    WizardState::onExit(event);
}

==> camitk_3.4.0.orig.tar.gz: camitk-3.4.0-Source/sdk/applications/wizard/ActionsCreationState.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

// Include .h file
#include "ActionsCreationState.h"
#include "ActionsCreationWidget.h"
#include "DorothyMainWindow.h"
#include "ActionExtensionCreationState.h"

// includes from coreschema
#include <ActionExtension.hxx>
#include <Actions.hxx>

/**  Constructor */
ActionsCreationState::ActionsCreationState(QString name, ActionsCreationWidget * widget, DorothyMainWindow * mainWindow, ActionExtensionCreationState * parent)
    : WizardState(name, widget, mainWindow, parent) {
    this->domActionExtension = NULL;
}

/**  Destructor */
ActionsCreationState::~ActionsCreationState() {}

void ActionsCreationState::resetDomActionExtension(cepcoreschema::ActionExtension * domActionExtension) {
    this->domActionExtension = domActionExtension;
    ActionsCreationWidget * actionsCreationWidget = dynamic_cast<ActionsCreationWidget *> (widget);
    if (actionsCreationWidget != NULL) {
        actionsCreationWidget->setToDefault();
    }
}

void ActionsCreationState::onEntry(QEvent * event) {
    WizardState::onEntry(event);

    ActionsCreationWidget * actionsCreationWidget = dynamic_cast<ActionsCreationWidget *> (widget);
    if (actionsCreationWidget != NULL) {
        QString actionExtensionName = domActionExtension->name().c_str();
        actionsCreationWidget->setGroupBoxTitle(actionExtensionName);

        actionsCreationWidget->emptyExistingActions();
        cepcoreschema::Actions theActions = domActionExtension->actions();
        cepcoreschema::Actions::action_iterator it;
        for (it = theActions.action().begin(); it != theActions.action().end(); it++) {
            QString actionName = (*it).name().c_str();
            actionsCreationWidget->addActionName(actionName);
        }
    }
}

void ActionsCreationState::onExit( QEvent * event ) {
    WizardState::onExit(event);
}
